@@ -52,9 +52,8 @@ enum{
 //Suda2
 #include "Suda2.h"
 
-#include "Pram.h"
+//#include "Pram.h"
 
-#include "freqCalc.h"
 #include "Measure_Risk.h"
 #include "Measure_Hierarchical.h"
 
